#!/bin/csh -f
#
# == Wrapper shell to produce dithered images of simulated sources
#
# NOTE: the use of this wrapper script requires the availability
#	of all inolved software and their dependencies.
#	multiking_addACS.pro, multidrizzle and auxiliary files
#	The pyraf trans task requires the _coeffs files used in orig dithering
#	Check the documentation of individual softwares for additional info.
#
# Written by M.Paolillo: 14/03/06
#
# Input parameters explanation:
# 1) File containing list of flt files on which you want to add simulations
# 2) Reference drizzled image for astrometry (usually obtained with flt files in 1)
# 3) Rootname of output drizzled image with simulated objects (simulated flt files will be named accordingly)
# 4) Simulated flt should be created as orig.flt+simul [a] or just blank+simul [n]?
# 5) Create GC [gc] or stellar [psf] objects?
# 6) Generate random sample whithin assigned range [p] or read obj.params from file [r]
# 7) File with list of simulated objects parameters
# 8) If (6)=p: numbero of objects to simulate; If (6)=r: File with parameters of objects to simulate 
# 9-11) If (6)=p: range [min max] of core radius, conc.index and mag of objects to simulate
#
#


if ($#argv < 8 | $1 == ^) then

echo =================================================
echo  'Usage: source multiking_wrapper.csh input_pars | tee multiking_wrapper.log'
echo
echo  '--> To create new simul: input_pars= 1) flt_list_file 2) ref.drz_sci image 3) output img.rootname 4) add old/new empty img. [a/n] 5) Simulate GC/PSF [gc/psf]'
echo  '6) perform/read simul.[p] 7) Output sim. list 8) Sim.obj. number'
echo  '9) Core range [min max] 10) Conc.index [min max] 11) V mag. range [min max]'
echo
echo  '--> To read simul.pars from file: input_pars= 1) flt_list_file 2) ref.drz_sci image 3) output img.rootname 4) add old/new empty img. [a/n] 5) Simulate GC/PSF [gc/psf]'
echo  '6) perform/read simul.[r] 7) Output sim. list 8) Input sim.obj. list'
echo
echo Input parameters explanation:
echo 1\) File containing list of flt files on which you want to add simulations
echo 2\) Reference drizzled image for astrometry \(usually obtained with flt files in 1\)
echo 3\) Rootname of output drizzled image with simulated objects \(simulated flt files will be named accordingly\)
echo 4\) Simulated flt should be created as orig.flt+simul \[a\] or just blank+simul \[n\]\?
echo 5\) Create GC \[gc\] or stellar \[psf\] objects\?
echo 6\) Generate random sample whithin assigned range \[p\] or read obj.params from file \[r\]
echo 7\) File with list of simulated objects parameters
echo 8\) If \(6\)=p: numbero of objects to simulate\; if \(6\)=r: File with parameters of objects to simulate 
echo 9-11\) If \(6\)=p: range [min max] of core radius, conc.index and mag of objects to simulate
echo =================================================

  exit
endif


# Rename old files
mv simul_flt.lst simul_flt.lst.old 
mv $3\_drz_sci.fits $3\_drz_sci.fits.old 
mv $3\_drz_wht.fits $3\_drz_wht.fits.old 

set fltnum = `wc -l $1`	# set input file number
echo Number of input flt files=$fltnum[1]

# Define parameters
set outimg = $3
set perf_read = $6
set outlist = $7
if ($perf_read == 'r') then
set inlist = $8
endif


#goto test	#to jump flt creation fot testing purposes
# LOOP on all flt files in the list
@ i = 0
cycle1:
@ i = $i + 1

set inputflt = `head -$i $1 | tail -1`
echo $i\) Using $inputflt

if ($perf_read == 'r') then
#Read simulation pars from list
idl << EOT1
.run multiking_addACS.pro
$inputflt
$2
$outimg\_flt$i.fits
$4
$5
$perf_read
$inlist
$outlist\_$i
EOT1
echo $outimg\_flt$i.fits >> simul_flt.lst
endif

if ($perf_read == 'p') then
#Perform simulations
idl << EOT2
.run multiking_addACS.pro
$inputflt
$2
$outimg\_flt$i.fits
$4
$5
$perf_read
$outlist\_$i
$8
$9 $10
$11 $12
$13 $14
EOT2
echo $outimg\_flt$i.fits >> simul_flt.lst

# Set to read for following flt files
set perf_read = r
set inlist = $outlist\_$i

endif

# Fine ciclo su tutti i cluster
if ($i < $fltnum[1]) goto cycle1


#Drizzle files togheter
test:
echo "===> Drizzling files together <==="
echo " WARNING: this step acquires all drizzle"
echo "          parameters from the reference drz_sci image \!\!"

# Run multidrizzle on simulated dithered files
source /scisoft/bin/Setup.csh
pyraf -s << EOT2
from pyraf.iraf import stsdas, dither
import pyfits
for l in range(1,$fltnum[1]+1):
   print l,")"
   j = 2*l-1
   # Drizzling extension 1
   if '$4' == 'n':
      iraf.drizzle.in_mask = ""		# Don't weight
      print "-- CAUTION:   ---------------------------------"
      print "No weights are applied when creating new image!"
      print "-----------------------------------------------"
   else:
      iraf.drizzle.in_mask = pyfits.open("$2")[0].header["D00"+str(j)+"MASK"]		# Weight according to ref.image
   iraf.drizzle.outweig="$outimg"+"_drz_wht.fits"
   iraf.drizzle.xsh = pyfits.open("$2")[0].header["D00"+str(j)+"XSH"]
   iraf.drizzle.ysh = pyfits.open("$2")[0].header["D00"+str(j)+"YSH"]
   iraf.drizzle.rot = pyfits.open("$2")[0].header["D00"+str(j)+"ROT"]
   iraf.drizzle.coeffs = pyfits.open("$2")[0].header["D00"+str(j)+"COEF"]
   iraf.drizzle.wt_scl = pyfits.open("$2")[0].header["D00"+str(j)+"WTSC"]
   iraf.drizzle.xgeoim = pyfits.open("$2")[0].header["D00"+str(j)+"XGIM"]
   iraf.drizzle.ygeoim = pyfits.open("$2")[0].header["D00"+str(j)+"YGIM"]
   iraf.drizzle.pixfrac = pyfits.open("$2")[0].header["D00"+str(j)+"PIXF"]
   iraf.drizzle.scale = pyfits.open("$2")[0].header["D00"+str(j)+"SCAL"]
   iraf.drizzle.shft_un = pyfits.open("$2")[0].header["D00"+str(j)+"SFTU"]
   iraf.drizzle.shft_fr = pyfits.open("$2")[0].header["D00"+str(j)+"SFTF"]
   iraf.drizzle.expkey = pyfits.open("$2")[0].header["D00"+str(j)+"EXKY"]
   iraf.drizzle.in_un = pyfits.open("$2")[0].header["D00"+str(j)+"INUN"]
   iraf.drizzle.out_un = pyfits.open("$2")[0].header["D00"+str(j)+"OUUN"]
   iraf.drizzle.fillval = pyfits.open("$2")[0].header["D00"+str(j)+"FVAL"]
   iraf.drizzle.outnx = pyfits.open("$2")[0].header["NAXIS1"]
   iraf.drizzle.outny = pyfits.open("$2")[0].header["NAXIS2"]
   iraf.drizzle("$outimg"+"_flt"+str(l)+".fits[sci,1]","$outimg"+"_drz_sci.fits")
   #
   # Drizzling extension 2 
   if '$4' == 'n':
      iraf.drizzle.in_mask = ""		# Don't weight
      print "-- CAUTION:   ---------------------------------"
      print "No weights are applied when creating new image!"
      print "-----------------------------------------------"
   else:
      iraf.drizzle.in_mask = pyfits.open("$2")[0].header["D00"+str(j+1)+"MASK"]		# Weight according to ref.image
   iraf.drizzle.xsh = pyfits.open("$2")[0].header["D00"+str(j+1)+"XSH"]
   iraf.drizzle.ysh = pyfits.open("$2")[0].header["D00"+str(j+1)+"YSH"]
   iraf.drizzle.rot = pyfits.open("$2")[0].header["D00"+str(j+1)+"ROT"]
   iraf.drizzle.coeffs = pyfits.open("$2")[0].header["D00"+str(j+1)+"COEF"]
   iraf.drizzle.wt_scl = pyfits.open("$2")[0].header["D00"+str(j+1)+"WTSC"]
   iraf.drizzle.xgeoim = pyfits.open("$2")[0].header["D00"+str(j+1)+"XGIM"]
   iraf.drizzle.ygeoim = pyfits.open("$2")[0].header["D00"+str(j+1)+"YGIM"]
   iraf.drizzle.pixfrac = pyfits.open("$2")[0].header["D00"+str(j+1)+"PIXF"]
   iraf.drizzle.scale = pyfits.open("$2")[0].header["D00"+str(j+1)+"SCAL"]
   iraf.drizzle.shft_un = pyfits.open("$2")[0].header["D00"+str(j+1)+"SFTU"]
   iraf.drizzle.shft_fr = pyfits.open("$2")[0].header["D00"+str(j+1)+"SFTF"]
   iraf.drizzle.expkey = pyfits.open("$2")[0].header["D00"+str(j+1)+"EXKY"]
   iraf.drizzle.in_un = pyfits.open("$2")[0].header["D00"+str(j+1)+"INUN"]
   iraf.drizzle.out_un = pyfits.open("$2")[0].header["D00"+str(j+1)+"OUUN"]
   iraf.drizzle.fillval = pyfits.open("$2")[0].header["D00"+str(j+1)+"FVAL"]
   iraf.drizzle.outnx = pyfits.open("$2")[0].header["NAXIS1"]
   iraf.drizzle.outny = pyfits.open("$2")[0].header["NAXIS2"]
   iraf.drizzle("$outimg"+"_flt"+str(l)+".fits[sci,2]","$outimg"+"_drz_sci.fits")

.exit
EOT2

# Remove inermediate files
rm -f $outimg\_flt?_single_*.fits
rm -f $outimg\_flt?_coeffs?.dat
rm -f $outimg\_flt?_final_*.fits

exit

